DeLU (Deep Learning Utilities)
==============================

.. include:: ../README.rst
   :start-after: __INCLUDE_0__

.. toctree::
   :hidden:

   version
   Source code <https://github.com/Yura52/delu>

.. toctree::
   :caption: API & Examples
   :hidden:

   api/delu
   api/cuda
   api/nn
   api/random
   api/utils.data
   api/tools

.. toctree::
   :caption: Deprecated API
   :hidden:

   api/deprecated

----

Indices and Tables
------------------

* :ref:`genindex`
* :ref:`modindex`
